@@ -23,8 +23,8 @@
 
 #include "filehandle.h"
 
-#include <Phonon/Global>
-#include <Phonon/Path>
+#include <phonon/Global>
+#include <phonon/Path>
 
 class PlaylistInterface;
 class QPixmap;
@@ -97,7 +97,6 @@ public slots:
     bool mute();
 
     void trackHasChanged(const Phonon::MediaSource &newSource);
-    void trackAboutToFinish();
 
     void setRandomPlayMode(const QString &randomMode);
 
